<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>CCanvas</name>
    <message>
        <location filename="../canvas/CCanvas.cpp" line="80"/>
        <source>No map view available.</source>
        <translation>Keine Kartenansicht verfügbar.</translation>
    </message>
</context>
<context>
    <name>CCommandProcessor</name>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="30"/>
        <source>Print debug output to console.</source>
        <translation>Debuginformation in der Konsole ausgeben.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="33"/>
        <source>Print debug output to logfile (temp. path).</source>
        <translation>Debuginformation in eine Datei schreiben (temp. Pfad).</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="36"/>
        <source>Do not show splash screen.</source>
        <translation>Das Anfangsbild nicht zeigen.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
        <source>QMapTool application locale.</source>
        <translation>Gebietsschema von QMapTool.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
        <source>code</source>
        <translation>Code</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
        <source>File with QMapTool configuration.</source>
        <translation>Eine Datei mit einer QMapTool-Konfiguration.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
</context>
<context>
    <name>CDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="35"/>
        <source>bad coordinate</source>
        <translation>ungültige Koordinate</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
        <source>Bad value for X pixel.</source>
        <translation>Ungültiger Wert fur den X Wert des Bildpunktes.</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
        <source>Bad value for Y pixel.</source>
        <translation>Ungültiger Wert fur den Y Wert des Bildpunktes.</translation>
    </message>
</context>
<context>
    <name>CDrawContextPixel</name>
    <message>
        <location filename="../canvas/CDrawContextPixel.cpp" line="63"/>
        <source>Failed to load</source>
        <translation>Datei laden fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>CDrawContextProj</name>
    <message>
        <location filename="../canvas/CDrawContextProj.cpp" line="59"/>
        <source>Failed to load</source>
        <translation>Datei laden fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>CGdalFile</name>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="45"/>
        <location filename="../helpers/CGdalFile.cpp" line="56"/>
        <location filename="../helpers/CGdalFile.cpp" line="78"/>
        <source>Error...</source>
        <translation>Fehler...</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="45"/>
        <location filename="../helpers/CGdalFile.cpp" line="56"/>
        <source>Failed to load file: %1</source>
        <translation>Datei laden fehlgeschlagen: %1</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="78"/>
        <source>File must be 8 bit palette or gray indexed.</source>
        <translation>Die Datei muss eine 8 Bit Farbpalette haben oder einen Graustufenindex.</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="170"/>
        <source>(color table)</source>
        <translation>(Farbtabelle)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="174"/>
        <source>(RGB)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="178"/>
        <source>(RGBA)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="182"/>
        <source>(unknown)</source>
        <translation>(unbekannt)</translation>
    </message>
</context>
<context>
    <name>CGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="33"/>
        <source>Select one of the corners and place the marker at the corresponding grid crossing on the map. All 4 corners have to be placed.</source>
        <translation>Wählen Sie eine Ecke aus und platzieren Sie die Markierung auf dem jeweiligen Gitterpunkt der Karte. Alle 4 Ecken müssen gesetzt werden.</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="133"/>
        <source>Point 1 - not set</source>
        <translation>Punkt 1 - nicht gesetzt</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="135"/>
        <source>Point 1 - ok</source>
        <translation>Punkt 1 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="139"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="143"/>
        <source>Point 1 - bad</source>
        <translation>Punkt 1 - falsch</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="151"/>
        <source>Point 2 - ok</source>
        <translation>Punkt 2 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="155"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="159"/>
        <source>Point 2 - bad</source>
        <translation>Punkt 2 - falsch</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="167"/>
        <source>Point 3 - ok</source>
        <translation>Punkt 3 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="171"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="175"/>
        <source>Point 3 - bad</source>
        <translation>Punkt 3 - falsch</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="183"/>
        <source>Point 4 - ok</source>
        <translation>Punkt 4 - ok</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="187"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="191"/>
        <source>Point 4 - bad</source>
        <translation>Punkt 4 - falsch</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="149"/>
        <source>Point 2 - not set</source>
        <translation>Punkt 2 - nicht gesetzt</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="165"/>
        <source>Point 3 - not set</source>
        <translation>Punkt 3 - nicht gesetzt</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
        <source>Point 4 - not set</source>
        <translation>Punkt 4 - nicht gesetzt</translation>
    </message>
</context>
<context>
    <name>CGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/CGridSelArea.cpp" line="30"/>
        <source>Select the area to be covered by the calculated reference points. Simply grab the corners of the selection rectangle with a left click and place them where you want with a second click.</source>
        <translation>Wählen Sie das Gebiet aus, für das Referenzpunkte berechnet werden sollen. Klicken Sie dazu einfach auf die Ecken des Auswahlrechtecks mit der linken Maustaste und platzieren die Ecke wo Sie wollen mit einem zweiten Klick.</translation>
    </message>
</context>
<context>
    <name>CGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/CGridSetRef.cpp" line="37"/>
        <source>Valid coordinate formats: If the projection is lat/lon all values have to be in degree, e.g. &quot;48.2&quot; or &quot;12.4&quot;. For all other projections values are either in multiple of meter or feet. If you are doing it wrong the entry field will turn red.</source>
        <translation>Gültige Koordinatenformate: Wenn die Projektion lat/lon Werte benötigt, müssen alle Eingaben in Grad sein, z.B. &quot;48.2&quot; oder &quot;12.4&quot;. Für alle anderen Projektionen sind die Eingaben entweder in Meter oder in Fuß. Wenn etwas falsch ist, werden die Eingabefelder rot.</translation>
    </message>
</context>
<context>
    <name>CHelp</name>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="42"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="80"/>
        <source>Content</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="81"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="82"/>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
</context>
<context>
    <name>CHelpIndex</name>
    <message>
        <location filename="../../common/help/CHelpIndex.cpp" line="26"/>
        <source>Search:</source>
        <translation>Suche:</translation>
    </message>
</context>
<context>
    <name>CHelpSearch</name>
    <message>
        <location filename="../../common/help/CHelpSearch.cpp" line="30"/>
        <source>Search:</source>
        <translation>Suche:</translation>
    </message>
</context>
<context>
    <name>CItemListWidget</name>
    <message>
        <location filename="../items/CItemListWidget.cpp" line="86"/>
        <source>Select files...</source>
        <translation>Dateien auswählen...</translation>
    </message>
</context>
<context>
    <name>CItemMapLayer</name>
    <message>
        <location filename="../items/CItemMapLayer.cpp" line="33"/>
        <source>Layer</source>
        <translation>Ebene</translation>
    </message>
</context>
<context>
    <name>CItemTreeWidget</name>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="133"/>
        <source>&lt;p&gt;The current map &lt;i&gt;&apos;%1&apos;&lt;/i&gt; does not match the projection of previous loaded maps. All map files need to have the same projection.&lt;/p&gt;&lt;p&gt;&lt;b&gt;This file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</source>
        <translation>&lt;p&gt;Die aktuelle Karte &lt;i&gt;&apos;%1&apos;&lt;/i&gt; entspricht nicht der Projektion der vorher geladenen Karten. Alle Kartendateien müssen die gleiche Projektion haben.&lt;/p&gt;&lt;p&gt;&lt;b&gt;Diese Datei:&lt;/b&gt; %s&lt;/p&gt;&lt;p&gt;&lt;b&gt;Erwartet:&lt;/b&gt; %3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="139"/>
        <source>Error...</source>
        <translation>Fehler...</translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="199"/>
        <source>Select files...</source>
        <translation>Dateien auswählen...</translation>
    </message>
</context>
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../misc.h" line="29"/>
        <source>File access failed...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc.h" line="30"/>
        <source>Failed to open %1 with error %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayCutMap</name>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
        <source>Delete mask...</source>
        <translation>Maske löschen...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
        <source>Are you sure to delete complete mask?</source>
        <translation>Wollen Sie wirklich die gesamte Maske löschen?</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="214"/>
        <source>Save mask...</source>
        <translation>Maske speichern...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="257"/>
        <source>Load mask...</source>
        <translation>Maske laden...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
        <source>Failed...</source>
        <translation>Fehlgeschlagen...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
        <source>Not a shape file.</source>
        <translation>Keine Shape-Datei.</translation>
    </message>
</context>
<context>
    <name>COverlayGridTool</name>
    <message>
        <location filename="../overlay/COverlayGridTool.cpp" line="33"/>
        <source>Before you proceed with &apos;ok&apos;:
Please cross check all data once again. A bad reference coordinate will ruin all the work. Also cross check if the selected area contains as many reference points as possible at the border. You can easily delete points outside the map in the Reference Tool. But it&apos;s much more effort to set additional points in case you miss some.  When you are done press &apos;ok&apos; to transfer the derived reference points to the Reference Tool.

The next step will be to use the Reference Tool to adjust the position of all reference points to the real grid position on the map.</source>
        <translation>Bevor Sie mit &apos;ok&apos; fortfahren:
Bitte überprüfen Sie alle Eingaben erneut. Ein falsche Referenzkoordinate ruiniert die ganze Arbeit. Überprüfen Sie bitte auch, ob das ausgewählte Gebiet an den Grenzen so viele Referenzpunkte wie möglich beinhaltet. Punkte außerhalb der Karte lassen sich recht einfach löschen. Neue Punkte hinzufügen, sollten welche fehlen, ist wesentlich aufwändiger. Wenn Sie fertig sind drücken Sie &apos;ok&apos;, um die berechneten Punkte in das Referenzwerkzeug zu übertragen. 

Im nächsten Schritte benutzen Sie das Referenzwerkzeug, um die Positionen von allen Referenzpunkten auf die tatsächlichen Gitterpunkte der Karte zu verschieben. </translation>
    </message>
</context>
<context>
    <name>COverlayRefMap</name>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="43"/>
        <source>If you used the Grid Tool you have to fine tune the reference points by placing them as much as possible on the grid crossing. Be aware that if you over scale you get jumping points by rounding effects. Be precise but do not make religion out of the task.
If your mouse focus is on the map you can use the N and B keys to jump forward an backward in the reference point list. 
The is also the option to fine tune the reference points in auto-mode. In this mode the next reference point is selected automatically right after you placed the current one. This is very convenient for a large number of reference points.</source>
        <translation>Wenn Sie das Gitterwerkzeug benutzt haben, müssen Sie die Punkte noch justieren, indem Sie sie auf die Gitterpunkte verschieben. Seien Sie sich bewusst, dass wenn Sie besonders nahe heranzoomen, die Punkte auf Grund von Rundungseffekten springen können. Seien sie beim Positionieren exakt, aber machen Sie daraus keine Religion.

Wenn ihr Mausfokus auf der Karte ist, können Sie die N und B Tasten benützen, um sich in der Referenzpunktliste vor und zurück zu bewegen.
Es gibt außerdem die Option, die Referenzpunkte im Automode zu justieren. In diesem Modus wird der nächste Referenzpunkt automatisch ausgewählt, nachdem Sie den aktuellen Punkt platziert haben. Diese Funktion ist sehr praktisch, wenn Sie eine große Anzahl an Punkten bearbeiten wollen.</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="519"/>
        <source>Save reference points...</source>
        <translation>Referenzpunkte speichern...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="554"/>
        <source>Load reference points...</source>
        <translation>Referenzpunkte laden...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="589"/>
        <source>Delete all reference points...</source>
        <translation>Alle Referenzpunkte löschen...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="590"/>
        <source>Are you sure to delete all reference points in the list?</source>
        <translation>Sind Sie sicher, dass Sie alle Referenzpunkte aus der Liste löschen wollen?</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
        <source>Delete...</source>
        <translation>Löschen...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
        <source>Delete all selected reference points?</source>
        <translation>Alle ausgewählten Referenzpunkte löschen?</translation>
    </message>
</context>
<context>
    <name>COverlayRefMapPoint</name>
    <message>
        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="40"/>
        <source>bad coordinate</source>
        <translation>ungültige Koordinate</translation>
    </message>
</context>
<context>
    <name>CProj</name>
    <message>
        <location filename="../../common/gis/proj_x.cpp" line="153"/>
        <source>The value
&apos;%1&apos;
is not a valid coordinate system definition:
%2</source>
        <translation>Die Eingabe
&apos;%1&apos;
ist keine gültige Koordinatensystemdefinition:
%2</translation>
    </message>
    <message>
        <location filename="../../common/gis/proj_x.cpp" line="162"/>
        <source>Lat/Lon projection is not allowed in this case.</source>
        <translation>Lat/Lon Projektion ist in diesem Fall nicht möglich.</translation>
    </message>
</context>
<context>
    <name>CProjWizard</name>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="45"/>
        <source> (Spheroid: %1)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="59"/>
        <source>north</source>
        <translation>Nord</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="60"/>
        <source>south</source>
        <translation>Süd</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="199"/>
        <source>Error...</source>
        <translation>Fehler...</translation>
    </message>
</context>
<context>
    <name>CSetupExtTools</name>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="61"/>
        <location filename="../setup/CSetupExtTools.cpp" line="62"/>
        <location filename="../setup/CSetupExtTools.cpp" line="63"/>
        <location filename="../setup/CSetupExtTools.cpp" line="64"/>
        <location filename="../setup/CSetupExtTools.cpp" line="65"/>
        <location filename="../setup/CSetupExtTools.cpp" line="66"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;nicht gefunden&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="77"/>
        <source>Select %1 binary...</source>
        <translation>Programm %1 auswählen...</translation>
    </message>
</context>
<context>
    <name>CShell</name>
    <message>
        <location filename="../shell/CShell.cpp" line="40"/>
        <source>Execution of external program `%1` failed: </source>
        <translation>Ausführen der externen Anwendung &apos;%1&apos; fehlgeschlagen:</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="43"/>
        <source>Process cannot be started.
</source>
        <translation>Der Prozess kann nicht gestartet werden.</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="44"/>
        <source>Make sure the required packages are installed, `%1` exists and is executable.
</source>
        <translation>Stellen Sie sicher, dass alle benötigten Pakete installiert sind, &apos;%1&apos; vorhanden und ausführbar ist.</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="49"/>
        <source>External process crashed.
</source>
        <translation>Der externe Prozess ist abgestürzt.</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="53"/>
        <source>An unknown error occurred.
</source>
        <translation>Ein unbekannter Fehler ist aufgetreten.</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="130"/>
        <source>!!! failed !!!
</source>
        <translation>!!! fehlgeschlagen !!!</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="143"/>
        <source>
Canceled by user&apos;s request.
</source>
        <translation>
Durch den Benutzer abgebrochen.</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="168"/>
        <source>!!! done !!!
</source>
        <translation>!!! fertig !!!</translation>
    </message>
</context>
<context>
    <name>CToolAddOverview</name>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="29"/>
        <source>Add Overviews</source>
        <translation>Übersichten hinzufügen</translation>
    </message>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="32"/>
        <source>Raster map files consume quite some memory if a larger area is displayed. Pre-calculated overview levels help to speed up loading and displaying the map. These overviews can be stored within the map file as well as an external file. GDAL can remove internally stored overviews, however it will not free the used space in the file. Therefore it&apos;s size will remain large. If you do not like that use the external option.</source>
        <translation>Rasterkarten benötigen recht viel Speicher, wenn ein größeres Gebiet angezeigt werden soll. Vorberechnete Übersichtsebenen helfen dabei, die Karte schnell zu laden und anzuzeigen. Diese Übersichtsebenen können in der Kartendatei oder als externe Datei gespeichert werden. GDAL kann zwar interne Übersichtsebenen entfernen, gibt dabei aber leider den Speicher nicht frei. Deswegen wird die Datei groß bleiben. Wenn Sie das nicht wünschen, dann sollten Sie die Option zur Erstellung einer externen Datei verwenden.</translation>
    </message>
</context>
<context>
    <name>CToolCutMap</name>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="29"/>
        <source>Cut Map</source>
        <translation>Karte freistellen</translation>
    </message>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="32"/>
        <source>Paper maps usually have a border you don&apos;t want to have. To combine maps seamlessly you have to cut that border, replacing it by transparent pixel. This tool allows you to define a cut line and it will add an alpha channel for transparency to your map.</source>
        <translation>Papierkarten haben üblicherweise einen Rand, den man nicht dabei haben will. Um Karten blattschnittfrei zu kombinieren, muss man diesen Rand ausschneiden und durch transparente Bildpunkte ersetzen. Dieses Werkzeug ermöglicht es Ihnen, eine Schnittmaske zu erstellen, um damit einen Alphakanal mit den transparenten Bildpunkten zu erstellen. </translation>
    </message>
</context>
<context>
    <name>CToolExport</name>
    <message>
        <location filename="../tool/CToolExport.cpp" line="29"/>
        <source>Export Maps</source>
        <translation>Karten exportieren</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="33"/>
        <source>To use the maps on your device you have to export them to the proprietary format supported by the device. Depending on the device this can vary from a single layer map to a map stack with maps of different scale.</source>
        <translation>Wenn Sie die Karten auf ihrem Gerät benützen wollen, müssen Sie diese in das jeweilige geschlossene Format. welches vom Gerät verwendet wird, exportieren. Abhängig vom Gerät kann das eine Karte mit einer einzelnen Auflösungsebene sein, oder eine mit mehreren Ebenen.</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="41"/>
        <source>Note: This tool will use all files in the list as a input. This will only work if all files have the same projection.</source>
        <translation>Hinweis: Dieses Werkzeug verwendet alle Dateien in der Liste als Eingabe. Das funktioniert nur, wenn alle Karten die selbe Projektion verwenden.</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="104"/>
        <source>Select filename...</source>
        <translation>Dateinamen auswählen...</translation>
    </message>
</context>
<context>
    <name>CToolGrid</name>
    <message>
        <location filename="../tool/CToolGrid.cpp" line="35"/>
        <source>By placing 4 reference points at the corners of a grid square and referencing them by their top left corner, the width and height, all the other grid points can be estimated.</source>
        <translation>Indem Sie 4 Referenzpunkte in den Ecken eines Gitterquadrates setzen und diese über die obere linke Ecke und die Breite und Höhe referenzieren, können alle anderen Gitterpunkte ungefähr berechnet werden.</translation>
    </message>
</context>
<context>
    <name>CToolPalettize</name>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="30"/>
        <source>Add Color Palette</source>
        <translation>Farbtabelle erzeugen</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="37"/>
        <source>Usually you use RGBA color while referencing a map because the large color space allows you to scale and rotate the map without any loss of quality. But it results into rather large files. The file size can be optimized by using a color palette instead of the RGBA color space. The impact on quality is low as long as you do not want to scale or rotate the map. If you want to combine files with a color palette all files need to have the same palette.</source>
        <translation>Üblicherweise benützt man RGBA Farben während man eine Karte referenziert, weil der große Farbraum einem erlaubt, die Karte ohne Qualitätseinbuße zu drehen und zu skalieren. Leider wird deswegen auch die Datei sehr groß. Die Größe kann optimiert werden, wenn man eine Farbpalette anstelle von RGBA verwendet. Die Qualitätseinbußen sind gering, solange man die Karte nicht drehen oder skalieren möchte. Wenn Sie mehrere Karten zusammenfügen wolle, müssen alle dieselbe Palette benützen.</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="49"/>
        <source>Note: This tool will use all files in the list as a combined input to derive an optimal palette. This will only work if all files have the same projection and scale.</source>
        <translation>Anmerkung: Dieses Werkzeug benützt alle Dateien in der Liste als gemeinsame Eingabe, um eine optimale Palette zu berechnen. Das kann nur funktionieren, wenn alle Dateien die gleiche Projektion und Skalierung haben.</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="114"/>
        <source>Select filename...</source>
        <translation>Dateinamen auswählen...</translation>
    </message>
</context>
<context>
    <name>CToolRefMap</name>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="32"/>
        <source>Reference Map</source>
        <translation>Karte referenzieren</translation>
    </message>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="35"/>
        <source>A scan of a paper map can be converted to a referenced raster map if you place at least three reference points on the map. The more points the better the result. If your map has a grid you can place points on that grid with the grid tool.</source>
        <translation>Eine gescannte Papierkarte kann in eine referenzierte Rasterkarte umgewandelt werden, indem Sie mindestens 3 Referenzpunkte auf der Karte angeben. Je mehr Punkte Sie setzen, desto besser. Wenn ihre Karte eine Gitter besitzt, können Sie Punkte auf dem Gitter mit dem Gitterwerkzeug setzen.</translation>
    </message>
</context>
<context>
    <name>IAbout</name>
    <message>
        <location filename="../IAbout.ui" line="14"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="26"/>
        <source>&lt;b&gt;QMapTool&lt;/b&gt;, Version</source>
        <translation>&lt;b&gt;QMapTool&lt;/b&gt;, Version</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="39"/>
        <location filename="../IAbout.ui" line="77"/>
        <location filename="../IAbout.ui" line="91"/>
        <location filename="../IAbout.ui" line="105"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="70"/>
        <source>Qt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="84"/>
        <source>GDAL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="98"/>
        <source>PROJ</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="121"/>
        <source>This software is licensed under GPL3 or any later version</source>
        <translation>Diese Software steht unter der GPL3 Lizenz, oder einer neueren Version</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="128"/>
        <source>© 2017 Oliver Eichler (oliver.eichler@gmx.de)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ICoordFormatSetup</name>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="14"/>
        <source>Coordinate Format...</source>
        <translation>Koordinatenformat...</translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="24"/>
        <source>N48° 53&apos; 39.6&quot; E13° 31&apos; 6.78&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="31"/>
        <source>N48.8943° E013.51855°</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="38"/>
        <source>N48° 53.660 E013° 31.113</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation>&lt;b&gt;Anmerkung:&lt;/b&gt; Bei einigen GUI Elementen wird die Änderung erst mit einem Neustart von QMapTool übernommen.</translation>
    </message>
</context>
<context>
    <name>IDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="25"/>
        <source>Coord. Map File [pixel]</source>
        <translation>Koord. Karte [pixel]</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="32"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="42"/>
        <source>y</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="49"/>
        <source>Coord. lat/lon WGS84 [°]</source>
        <translation>Koord. lat/lon WGS84 [°]</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="59"/>
        <source>Bad position format. Must be: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
or
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation>Falsches Format. Entweder: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
oder
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</translation>
    </message>
</context>
<context>
    <name>IGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="150"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="224"/>
        <source>Set Area</source>
        <translation>Abdeckung</translation>
    </message>
</context>
<context>
    <name>IGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="35"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="35"/>
        <source>Grid Projection:</source>
        <translation>Gitterprojektion:</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="47"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="60"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="72"/>
        <source>Easting</source>
        <translation>Ostwert</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="82"/>
        <source>Horiz. Spacing</source>
        <translation>horiz. Abstand</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="92"/>
        <source>Northing</source>
        <translation>Nordwert</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="102"/>
        <source>Vert. Spacing</source>
        <translation>vert. Abstand</translation>
    </message>
</context>
<context>
    <name>IItemListWidget</name>
    <message>
        <location filename="../items/IItemListWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation>Kartendateien zur Liste hinzufügen</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="43"/>
        <location filename="../items/IItemListWidget.ui" line="60"/>
        <location filename="../items/IItemListWidget.ui" line="77"/>
        <location filename="../items/IItemListWidget.ui" line="94"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation>Ausgewählte Dateien aus der Liste entfernen.</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation>Die komplette Kartendateiliste löschen. </translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation>Die aktuell ausgewählte Karte erneut laden.</translation>
    </message>
</context>
<context>
    <name>IItemTreeWidget</name>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation>Kartendateien zur Liste hinzufügen</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="43"/>
        <location filename="../items/IItemTreeWidget.ui" line="60"/>
        <location filename="../items/IItemTreeWidget.ui" line="77"/>
        <location filename="../items/IItemTreeWidget.ui" line="94"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation>Ausgewählte Dateien aus der Liste entfernen.</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation>Die komplette Kartendateiliste löschen.</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation>Die aktuell ausgewählte Karte erneut laden.</translation>
    </message>
</context>
<context>
    <name>IMainWindow</name>
    <message>
        <location filename="../IMainWindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="32"/>
        <source>Setup</source>
        <translation>Einrichten</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="41"/>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="47"/>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="52"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="68"/>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="101"/>
        <source>Shell</source>
        <translation>Shell</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="120"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="129"/>
        <source>Ext. Tools</source>
        <translation>Ext. Werkzeuge</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="132"/>
        <source>Setup paths to external tools, like gdalwarp etc.</source>
        <translation>Pfade zu den externen Werkzeugen, wie z.B. gdalwarp, einrichten.</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="144"/>
        <location filename="../IMainWindow.ui" line="147"/>
        <source>Flip Mouse Wheel</source>
        <translation>Mausrad umdrehen</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="156"/>
        <location filename="../IMainWindow.ui" line="159"/>
        <source>Setup Units</source>
        <translation>Einheiten einrichten</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="168"/>
        <source>Setup Coord. Format</source>
        <translation>Koordinatenformat einrichten</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="171"/>
        <source>Change the format coordinates are displayed</source>
        <translation>Das Format, in dem die Koordinaten angezeigt werden, ändern</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="182"/>
        <source>Show Tool Help</source>
        <translation>Hilfstexte anzeigen</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="191"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="194"/>
        <source>F1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IOverlayCutMap</name>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="35"/>
        <source>Just move the map and zoom.</source>
        <translation>Die Karte verschieben und zoomen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="58"/>
        <source>Add point to mask.</source>
        <translation>Punkte zur Maske hinzufügen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="61"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="84"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="107"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="137"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="158"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="175"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="81"/>
        <source>Move point of mask.</source>
        <translation>Maskenpunkte verschieben.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="104"/>
        <source>Remove point from mask.</source>
        <translation>Punkte aus der Maske entfernen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="134"/>
        <source>Remove complete cut mask.</source>
        <translation>Die komplette Freistellmaske entfernen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="155"/>
        <source>Load cut mask from shape file.</source>
        <translation>Freistellmaske aus einer Shapedatei laden.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="172"/>
        <source>Save cut mask to shape file.</source>
        <translation>Freistellmaske in einer Shapedatei speichern.</translation>
    </message>
</context>
<context>
    <name>IOverlayGridTool</name>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="145"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>IOverlayRefMap</name>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="40"/>
        <source>Just move the map and zoom.</source>
        <translation>Die Karte verschieben und zoomen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="63"/>
        <source>Add reference point.</source>
        <translation>Referenzpunkte hinzufügen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="66"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="89"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="112"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="135"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="165"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="179"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="200"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="217"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="244"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="326"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="86"/>
        <source>Move reference point.</source>
        <translation>Referenzpunkte verschieben.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="109"/>
        <source>Remove single reference point.</source>
        <translation>Referenzpunkte löschen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="132"/>
        <source>Move reference points with auto mode. This will pickup the next point after you moved a reference point.</source>
        <translation>Referenzpunkte im Automode verschieben. Nachdem der aktuelle Punkt verschoben wurde, wird automatisch der Nächste genommen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="162"/>
        <source>Remove all reference points.</source>
        <translation>Alle Referenzpunkte löschen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="176"/>
        <source>Switch to the Grid Tool.</source>
        <translation>Auf das Gitterwerkzeug umschalten.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="197"/>
        <source>Load reference points from GCP file.</source>
        <translation>Referenzpunkte aus einer GCP Datei lesen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="214"/>
        <source>Save reference points into GCP file.</source>
        <translation>Referenzpunkte in eine GCP Datei speichern.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="241"/>
        <source>Sort list of reference points.</source>
        <translation>Die Liste der Referenzpunkte sortieren.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="281"/>
        <source>(x, y)[pixel]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="286"/>
        <source>(lat, lon)[°]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="294"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="304"/>
        <source>Final Map Projection:</source>
        <translation>Endgültige Kartenprojektion:</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="316"/>
        <source>Enter a valid projection string. Valid strings are &quot;+proj...&quot; or &quot;EPSG:...&quot;.</source>
        <translation>Geben Sie einen gültigen Projektionstext ein. Gültige Formen sind &quot;+proj...&quot; oder &quot;EPSG:...&quot;.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="323"/>
        <source>Start projection wizard.</source>
        <translation>Den Projektionsassistenten öffnen.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="343"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>IProjWizard</name>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="14"/>
        <source>PROJ Wizard</source>
        <translation>PROJ Assistent</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="29"/>
        <source>Mercator</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="38"/>
        <source>UTM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="45"/>
        <source>zone</source>
        <translation>Zone</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="82"/>
        <source>user defined</source>
        <translation>benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="94"/>
        <source>Datum</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="104"/>
        <source>World Mercator (OSM)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="124"/>
        <source>Result:</source>
        <translation>Ergebnis:</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="138"/>
        <source>UPS North (North Pole)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="145"/>
        <source>UPS South (South Pole)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="152"/>
        <source>Projection</source>
        <translation>Projektion</translation>
    </message>
</context>
<context>
    <name>ISetupExtTools</name>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="14"/>
        <source>Setup Ext. Tools</source>
        <translation>Externe Werkzeuge einstellen</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="22"/>
        <location filename="../setup/ISetupExtTools.ui" line="64"/>
        <location filename="../setup/ISetupExtTools.ui" line="99"/>
        <location filename="../setup/ISetupExtTools.ui" line="173"/>
        <location filename="../setup/ISetupExtTools.ui" line="194"/>
        <location filename="../setup/ISetupExtTools.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;nicht gefunden&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="32"/>
        <location filename="../setup/ISetupExtTools.ui" line="53"/>
        <location filename="../setup/ISetupExtTools.ui" line="74"/>
        <location filename="../setup/ISetupExtTools.ui" line="88"/>
        <location filename="../setup/ISetupExtTools.ui" line="135"/>
        <location filename="../setup/ISetupExtTools.ui" line="149"/>
        <location filename="../setup/ISetupExtTools.ui" line="183"/>
        <location filename="../setup/ISetupExtTools.ui" line="211"/>
        <location filename="../setup/ISetupExtTools.ui" line="225"/>
        <location filename="../setup/ISetupExtTools.ui" line="239"/>
        <location filename="../setup/ISetupExtTools.ui" line="264"/>
        <location filename="../setup/ISetupExtTools.ui" line="275"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="112"/>
        <source>gdal_translate:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="43"/>
        <source>gdalbuildvrt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="166"/>
        <source>gdaladdo:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="125"/>
        <source>gdalwarp:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="29"/>
        <location filename="../setup/ISetupExtTools.ui" line="132"/>
        <location filename="../setup/ISetupExtTools.ui" line="180"/>
        <location filename="../setup/ISetupExtTools.ui" line="208"/>
        <location filename="../setup/ISetupExtTools.ui" line="222"/>
        <source>Setup user defined path.</source>
        <translation>Benutzerdefinierten Pfad einstellen.</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="201"/>
        <source>qmt_rgb2pct</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="50"/>
        <location filename="../setup/ISetupExtTools.ui" line="71"/>
        <location filename="../setup/ISetupExtTools.ui" line="85"/>
        <location filename="../setup/ISetupExtTools.ui" line="146"/>
        <location filename="../setup/ISetupExtTools.ui" line="236"/>
        <source>Reset user defined path setup.</source>
        <translation>Benutzerdefinierten Pfad zurücksetzen.</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="250"/>
        <source>qmt_map2jnx</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="288"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Usually QMapTool should detect all external tools by itself. If it does not, it&apos;s a bad setup and you should fix the PATH variable of your system. You can setup the paths manually, too, if you know what you are doing. But please keep in mind that GDAL needs a proper environment setup to function properly. If it&apos;s not setup properly you might get results but these can be off grid.</source>
        <translation>&lt;b&gt;Anmerkung:&lt;/b&gt; Normalerweise sollte QMapTool alle externen Werkzeuge selber finden. Wenn das nicht gelingt, liegt es in der Regel an einer schlechten Einstellung und Sie sollten die PATH Variable ihres Systems überprüfen. Man kann die Werkzeugpfade auch selber setzen. Vorausgesetzt, man weiß was man macht. Bitte bedenken Sie, dass GDAL eine ordentlich aufgesetzte Umgebung benötigt, um fachgerecht zu funktionieren. Wenn dem nicht so ist, können durchaus Ergebnisse erzielt werden, diese können aber verschoben sein.</translation>
    </message>
</context>
<context>
    <name>ITimeZoneSetup</name>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="14"/>
        <source>Setup Timezone ...</source>
        <translation>Zeitzone einstellen...</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="22"/>
        <source>UTC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="32"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="42"/>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="75"/>
        <source>Print date/time in </source>
        <translation>Datum/Zeit anzeigen im</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="82"/>
        <source>long format, or</source>
        <translation>langen Format</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="92"/>
        <source>short format</source>
        <translation>kurzen Format</translation>
    </message>
</context>
<context>
    <name>IToolAddOverview</name>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="59"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="119"/>
        <source>:2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="126"/>
        <source>:4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="133"/>
        <source>:8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="140"/>
        <source>:16</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="147"/>
        <source>:32</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="154"/>
        <source>:64</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="164"/>
        <source>Remove all overview levels from map file.</source>
        <translation>Alle Übersichten aus der Kartendatei entfernen.</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="167"/>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="174"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation>Die Übersichten nicht in der Datei selbst anlegen. Als extra Datei hinzufügen.</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="177"/>
        <source>Overview as external file</source>
        <translation>Übersichten als externe Datei</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="207"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="221"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="232"/>
        <source>For all files</source>
        <translation>Für alle Dateien</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>IToolCutMap</name>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="59"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="114"/>
        <source>Output filename suffix</source>
        <translation>Suffix der Ausgabedatei</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="133"/>
        <source>_cut</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="148"/>
        <source>Create overviews for result.</source>
        <translation>Übersichten für das Ergebnis erzeugen.</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="155"/>
        <source>GDAL Parameters</source>
        <translation>GDAL Parameter</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="183"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="197"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="208"/>
        <source>For all files</source>
        <translation>Für alle Dateien</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="233"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdalwarp&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="243"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>IToolExport</name>
    <message>
        <location filename="../tool/IToolExport.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="59"/>
        <location filename="../tool/IToolExport.ui" line="72"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="83"/>
        <source>Garmin BirdsEye (*.jnx)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="88"/>
        <source>TwoNav Raster (*.rmap)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="101"/>
        <source>not implemented yet</source>
        <translation>noch nicht eingebaut</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="112"/>
        <source>Target File</source>
        <translation>Zieldatei</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="130"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="144"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="173"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_map2jnx&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;qmt_map2jnx&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="184"/>
        <source>Target Filename</source>
        <translation>Dateiname der Zieldatei</translation>
    </message>
</context>
<context>
    <name>IToolExportJnx</name>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="35"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="81"/>
        <source>BirdsEye</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="50"/>
        <source>Product ID</source>
        <translation>Produkt ID</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="57"/>
        <source>Copyright notice</source>
        <translation>Urheberhinweis</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="64"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="95"/>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="71"/>
        <source>Product name</source>
        <translation>Produktname</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="88"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="105"/>
        <source>JPEG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="133"/>
        <source>Quality</source>
        <translation>Qualität
</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="140"/>
        <source>Chroma subsampling</source>
        <translation>Halbttonunterabtastung</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="148"/>
        <source>411</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="153"/>
        <source>422</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="158"/>
        <source>444</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="169"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="184"/>
        <source>Z-Order</source>
        <translation>Reihenfolge (Z-Achse)</translation>
    </message>
</context>
<context>
    <name>IToolGDALGroupBox</name>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="17"/>
        <source>GDAL Parameters</source>
        <translation>GDAL Parameter</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="50"/>
        <source>Resampling</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="84"/>
        <source>Compression</source>
        <translation>Kompression</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="118"/>
        <source>Tiled</source>
        <translation>Kacheln</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="144"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="188"/>
        <source>Other:</source>
        <translation>Weitere:</translation>
    </message>
</context>
<context>
    <name>IToolGrid</name>
    <message>
        <location filename="../tool/IToolGrid.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="56"/>
        <source>Grid Tool</source>
        <translation>Gitterwerkzeug</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="65"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="99"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="110"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="134"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>IToolOverviewGroupBox</name>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="71"/>
        <source>:2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="78"/>
        <source>:4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="85"/>
        <source>:8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="92"/>
        <source>:16</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="99"/>
        <source>:32</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="106"/>
        <source>:64</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="119"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation>Die Übersichten nicht in der Datei selber anlegen. Als extra Datei hinzufügen.</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="122"/>
        <source>Overview as external file</source>
        <translation>Übersichten als externe Datei</translation>
    </message>
</context>
<context>
    <name>IToolPalettize</name>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="65"/>
        <location filename="../tool/IToolPalettize.ui" line="78"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="96"/>
        <source>Single files, filename suffix</source>
        <translation>Einzelne Dateien, Dateinamensuffix</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="109"/>
        <source>_8bit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="123"/>
        <source>Combined file, filename:</source>
        <translation>In einer Datei zusammenfassen, Dateiname:</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="135"/>
        <source>Embed result into *.vrt file.</source>
        <translation>Ergebnis in eine *.vrt Datei einbetten.</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="142"/>
        <source>Create overviews for result.</source>
        <translation>Übersichten für das Ergebnis erzeugen.</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="149"/>
        <source>GDAL Parameter</source>
        <translation>GDAL Parameter</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="177"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="191"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="220"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="230"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdal_translate&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="240"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_rgb2pct&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;qmt_rgb2pct&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="254"/>
        <source>Select filename</source>
        <translation>Dateinamen auswählen</translation>
    </message>
</context>
<context>
    <name>IToolRefMap</name>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="59"/>
        <source>do not translate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="113"/>
        <source>Output filename suffix</source>
        <translation>Suffix der Ausgabedatei</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="132"/>
        <source>_ref</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="144"/>
        <source>Embed result into *.vrt file.</source>
        <translation>Ergebnis in eine *.vrt Datei einbetten.</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="151"/>
        <source>Create overviews for result.</source>
        <translation>Übersichten für das Ergebnis erzeugen.</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="158"/>
        <source>GDAL Parameters</source>
        <translation>GDAL Parameter</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="186"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="200"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="211"/>
        <source>For all files</source>
        <translation>Für alle Dateien</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="236"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdalwarp&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="246"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdal_translate&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="256"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot;nicht gefunden. Bitte überprüfen Sie die Einstellungen!&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>IUnit</name>
    <message>
        <location filename="../units/IUnit.cpp" line="714"/>
        <location filename="../units/IUnit.cpp" line="721"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="715"/>
        <source>Bad position format. Must be: &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot; or &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation>Falsches Format. Entweder: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
oder
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="721"/>
        <source>Position values out of bounds. </source>
        <translation>Positionswerte außerhalb der Grenzen. </translation>
    </message>
</context>
<context>
    <name>IUnitsSetup</name>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="14"/>
        <source>Setup units...</source>
        <translation>Einheiten einrichten...</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="24"/>
        <source>Nautical</source>
        <translation>nautisch</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="31"/>
        <source>Imperial</source>
        <translation>imperial</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="38"/>
        <source>Metric</source>
        <translation>metrisch</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation>&lt;b&gt;Anmerkung:&lt;/b&gt; Bei einigen GUI Elementen wird die Änderung erst mit einem Neustart von QMapTool übernommen.</translation>
    </message>
</context>
</TS>
